@@ -80,6 +80,7 @@ def order_cols(df, cols, name):
 
 
 def order_cols_with_meta(df, cols, meta_cols, col_name, meta_name):
+    #  TODO - merging might be an issue with this function
     """Reorder values in columns to be in alphabetical order, keeping track of columns with
     meta-information
 
@@ -350,7 +351,8 @@ def fit_anchor_model(df, fit_genes, scale, scale_alpha=0.05, x_col='lfc_target',
         train_df = df
     train_x = sm.add_constant(train_df[x_col])
     model_fit = sm.OLS(train_df[y_col], train_x).fit()
-    model_info = {'R2': model_fit.rsquared, 'f_pvalue': model_fit.f_pvalue}
+    model_info = {'R2': model_fit.rsquared, 'f_pvalue': model_fit.f_pvalue, 'const': model_fit.params.const,
+                  'beta': model_fit.params.lfc_target}
     test_df = df.copy()
     predictions = model_fit.predict(sm.add_constant(test_df[x_col]))
     test_df['residual'] = test_df[y_col] - predictions
@@ -621,7 +623,6 @@ def calc_dlfc(df, base_lfcs):
 
 
 def get_guide_dlfcs(lfc_df, ctl_genes):
-    warnings.warn('delta-LFC functions are not under active development', DeprecationWarning, stacklevel=2)
     """Calculate delta-LFC's at the guide level
 
     Model the LFC of each combination as the sum of each guide when paired with controls. The difference from this
@@ -647,17 +648,45 @@ def get_guide_dlfcs(lfc_df, ctl_genes):
     """
     check_guide_input(lfc_df)
     #  get base lfcs using anchor framework
-    anchor_df = build_anchor_df(lfc_df)
-    melted_anchor_df = melt_df(anchor_df)
-    base_lfcs = get_base_score(melted_anchor_df, ctl_genes)
-    #  calculate delta-log-fold changes without generating an anchor df
+    melted_lfc_df = melt_df(lfc_df)
+    reordered_guides = order_cols_with_meta(melted_lfc_df, [0, 1], [2, 3], 'guide', 'gene')
+    dedup_guide_lfcs = aggregate_guide_lfcs(reordered_guides)
+    melted_anchor_df = build_anchor_df(dedup_guide_lfcs)
+    guide_base_score = get_base_score(melted_anchor_df, ctl_genes)
+    no_control_guides = get_no_control_guides(melted_anchor_df, guide_base_score)
+    #  calculate delta-log-fold changes
+    warn_no_control_guides(melted_anchor_df, no_control_guides)
     melted_df = melt_df(lfc_df)
-    guide_dlfc = calc_dlfc(melted_df, base_lfcs)
+    guide_dlfc = calc_dlfc(melted_df, guide_base_score)
     return guide_dlfc
 
 
-def get_gene_dlfcs(guide_dlfcs, stat='dlfc'):
-    warnings.warn('delta-LFC functions are not under active development', DeprecationWarning, stacklevel=2)
+def get_base_lfc_from_dlfc(dlfc_df):
+    """Calculate gene level base lfcs from the guide-level dLFC dataframe
+
+    Parameters
+    ----------
+    dlfc_df: DataFrame
+        DataFrame of delta log-fold changes
+
+    Returns
+    -------
+    DataFrame
+        With columns gene, condition, base_lfc
+    """
+    gene1 = dlfc_df.columns[2]
+    gene2 = dlfc_df.columns[3]
+    guide1_base = 'lfc_' + dlfc_df.columns[0] + '_base'
+    guide2_base = 'lfc_' + dlfc_df.columns[1] + '_base'
+    base_lfcs = (pd.concat([dlfc_df.rename({gene1: 'gene', guide1_base: 'base_lfc'}, axis=1),
+                            dlfc_df.rename({gene2: 'gene', guide2_base: 'base_lfc'}, axis=1)])
+                 .groupby(['condition', 'gene'])
+                 .agg({'base_lfc': 'mean'})
+                 .reset_index())
+    return base_lfcs
+
+
+def get_gene_dlfcs(guide_dlfcs, stat='dlfc_z'):
     """Combine dLFCs at the gene level
 
     Parameters
@@ -676,5 +705,12 @@ def get_gene_dlfcs(guide_dlfcs, stat='dlfc'):
     pop_stats = get_pop_stats(ordered_df, stat)
     combined_z = combine_statistic(ordered_df, pop_stats, stat)
     avg_lfc = get_avg_score(ordered_df, 'lfc')
-    gene_results = (avg_lfc.merge(combined_z, how='inner', on=['condition', 'gene_a', 'gene_b']))
+    base_lfcs = get_base_lfc_from_dlfc(guide_dlfcs)
+    gene_results = (avg_lfc.merge(base_lfcs, how='inner', left_on=['condition', 'gene_a'],
+                                  right_on=['condition', 'gene'])
+                    .drop('gene', axis=1)
+                    .merge(base_lfcs, how='inner', left_on=['condition', 'gene_b'],
+                           right_on=['condition', 'gene'], suffixes=['_a', '_b'])
+                    .drop('gene', axis=1)
+                    .merge(combined_z, how='inner', on=['condition', 'gene_a', 'gene_b']))
     return gene_results
